@@ -14,6 +14,7 @@ from numpy import (
     cumsum,
     zeros,
     shape,
+    max as np_max,
 )
 
 from SciDataTool.Functions.Plot.init_fig import init_fig
@@ -52,6 +53,10 @@ def plot_2D(
     font_size_label=10,
     font_size_legend=8,
     is_show_legend=True,
+    scale_units="x",
+    scale=None,
+    width=0.005,
+    symbol=".",
 ):
     """Plots a 2D graph (curve, bargraph or barchart) comparing fields in Ydatas
 
@@ -107,6 +112,12 @@ def plot_2D(
         True to show figure after plot
     win_title : str
         Title of the plot window
+    scale_units : str
+        arrow lenght scale factor reference {'width', 'height', 'dots', 'pouces', 'x', 'y', 'xy'}
+    scale : float
+        arrow lenght factor
+    width : float
+        arrow width factor
     """
 
     # Set is_show_fig if is None
@@ -160,10 +171,9 @@ def plot_2D(
         # Repeat linewidths
         m = int(ceil(ndatas / len(linewidth_list)))
         linewidth_list = linewidth_list * m
-    if 1 == len(legend_list) < ndatas or len(legend_list) == 0:
-        # Set no legend for all curves
-        legend_list = list(repeat("", ndatas))
+    if (len(legend_list) == 1 and legend_list[0] == "") or len(legend_list) == 0:
         no_legend = True
+        legend_list = ["" for i in range(ndatas)]
     else:
         no_legend = False
 
@@ -243,9 +253,23 @@ def plot_2D(
         for i in range(ndatas):
             x = [e[0] for e in Xdatas[i_Xdatas[i]]]
             y = [e[1] for e in Xdatas[i_Xdatas[i]]]
-            vect_list = split(Ydatas[i], 2)
-            ax.quiver(x, y, squeeze(vect_list[0]), squeeze(vect_list[1]))
+            ax.quiver(
+                x,
+                y,
+                Ydatas[0][:, 0],
+                Ydatas[0][:, 1],
+                color=color_list[i],
+                scale_units=scale_units,
+                scale=scale,
+                width=width,
+                minshaft=2,
+                zorder=10,
+                label=legend_list[i],
+                headwidth=2,
+                headlength=4,
+            )
             ax.axis("equal")
+
     elif type_plot == "curve_point":
         for i in range(ndatas):
             ax.plot(
@@ -260,23 +284,22 @@ def plot_2D(
             ax.plot(
                 Xdatas[i_Xdatas[i]],
                 Ydatas[i],
-                ".",
+                symbol,
                 markerfacecolor=color_list[i],
                 markeredgecolor=color_list[i],
                 markersize=10,
-                picker=True,
-                pickradius=5,
             )
     elif type_plot == "point":
         for i in range(ndatas):
             ax.plot(
                 Xdatas[i_Xdatas[i]],
                 Ydatas[i],
-                ".",
+                symbol,
                 label=legend_list[i],
                 markerfacecolor=color_list[i],
                 markeredgecolor=color_list[i],
                 markersize=10,
+                mew=linewidth_list[i],
                 picker=True,
                 pickradius=5,
             )
@@ -340,7 +363,8 @@ def plot_2D(
     if is_grid:
         ax.grid()
 
-    if ndatas > 1 and not no_legend:
+    # if ndatas > 1 and not no_legend:
+    if not no_legend:
         ax.legend(prop={"family": font_name, "size": font_size_legend})
 
     if not is_show_legend:
