@@ -36,6 +36,7 @@ def plot_3D(
     is_logscale_z=False,
     is_disp_title=True,
     type_plot="stem",
+    is_contour=False,
     save_path=None,
     is_show_fig=None,
     is_switch_axes=False,
@@ -91,8 +92,10 @@ def plot_3D(
         boolean indicating if the z-axis must be set in logarithmic scale
     is_disp_title : bool
         boolean indicating if the title must be displayed
-    type : str
+    type_plot : str
         type of 3D graph : "stem", "surf", "pcolor" or "scatter"
+    is_contour : bool
+        True to show contour line if type_plot = "pcolor"
     save_path : str
         full path including folder, name and extension of the file to save if save_path is not None
     is_show_fig : bool
@@ -206,6 +209,15 @@ def plot_3D(
         if is_logscale_z:
             ax.zscale("log")
     elif type_plot == "pcolor":
+        Zdata[Zdata < z_min] = z_min
+        Zdata[Zdata > z_max] = z_max
+        # Handle descending order axes (e.g. spectrogram of run-down in freq/rpm map)
+        if Ydata[-1] < Ydata[0]:
+            Ydata = Ydata[::-1]
+            Zdata = Zdata[:, ::-1]
+        if Xdata[-1] < Xdata[0]:
+            Xdata = Xdata[::-1]
+            Zdata = Zdata[::-1, :]
         im = NonUniformImage(
             ax,
             interpolation="bilinear",
@@ -215,6 +227,8 @@ def plot_3D(
         )
         im.set_data(Xdata, Ydata, Zdata.T)
         ax.images.append(im)
+        if is_contour:
+            ax.contour(Xdata, Ydata, Zdata.T, colors="black", linewidths=0.8)
         clb = fig.colorbar(im, ax=ax, format=clb_format)
         clb.ax.set_title(zlabel, fontsize=font_size_legend, fontname=font_name)
         clb.ax.tick_params(labelsize=font_size_legend)
