@@ -18,6 +18,8 @@ def extract_slices(self, values, axes_list):
         values of the field
     """
 
+    axes_dict_other = {}
+
     # Extract the slices of the field
     for index, axis in enumerate(self.axes):
         is_match = False
@@ -30,5 +32,6 @@ def extract_slices(self, values, axes_list):
                 ):
                     values = take(values, axis_requested.indices, axis=index)
         if not is_match:  # Axis was not specified -> take slice at the first value
+            axes_dict_other[axis.name] = [axis.get_values()[0], axis.unit]
             values = take(values, [0], axis=index)
-    return values
+    return values, axes_dict_other
