@@ -23,6 +23,7 @@ from numpy import (
 def plot_2D_Data(
     self,
     *arg_list,
+    axis_data=None,
     is_norm=False,
     unit="SI",
     data_list=[],
@@ -50,7 +51,7 @@ def plot_2D_Data(
     fund_harm_dict=None,
     is_show_fig=None,
     win_title=None,
-    thresh=0.02,
+    thresh=None,
     font_name="arial",
     font_size_title=12,
     font_size_label=10,
@@ -166,7 +167,9 @@ def plot_2D_Data(
     data_list2 = [self] + data_list
     for i, d in enumerate(data_list2):
         if is_fft:
-            result = d.get_magnitude_along(arg_list, unit=unit, is_norm=is_norm)
+            result = d.get_magnitude_along(
+                arg_list, axis_data=axis_data, unit=unit, is_norm=is_norm
+            )
             if i == 0:
                 axes_list = result.pop("axes_list")
                 axes_dict_other = result.pop("axes_dict_other")
@@ -174,7 +177,9 @@ def plot_2D_Data(
             Ydatas.append(result.pop(d.symbol))
             Xdatas.append(result[list(result)[0]])
         else:
-            result = d.get_along(arg_list, unit=unit, is_norm=is_norm)
+            result = d.get_along(
+                arg_list, axis_data=axis_data, unit=unit, is_norm=is_norm
+            )
             if i == 0:
                 axes_list = result.pop("axes_list")
                 axes_dict_other = result.pop("axes_dict_other")
@@ -204,6 +209,7 @@ def plot_2D_Data(
                 "oneperiod",
                 "antiperiod",
                 "smallestperiod",
+                "axis_data",
             ]
             and len(axis.values) > 1
         ):
@@ -344,11 +350,18 @@ def plot_2D_Data(
 
     # Call generic plot function
     if is_fft:
+
+        if thresh is None:
+            if self.normalizations is not None and "ref" in self.normalizations.keys():
+                thresh = self.normalizations["ref"]
+            else:
+                thresh = 0.02
+
         freqs = Xdatas[0]
         indices = [
             ind
             for ind, y in enumerate(Ydatas[0])
-            if abs(y) > abs(0.02 * np_max(Ydatas[0]))
+            if abs(y) > abs(thresh * np_max(Ydatas[0]))
         ]
         xticks = unique(insert(0, 0, freqs[indices]))
 
